/*     */ package org.apache.batik.script.rhino;
/*     */ 
/*     */ import java.io.IOException;
/*     */ import java.io.Reader;
/*     */ import java.io.Writer;
/*     */ import java.net.URL;
/*     */ import java.security.AccessControlContext;
/*     */ import java.security.AccessController;
/*     */ import java.security.PrivilegedAction;
/*     */ import java.util.Iterator;
/*     */ import java.util.LinkedList;
/*     */ import java.util.List;
/*     */ import java.util.Locale;
/*     */ import org.apache.batik.bridge.InterruptedBridgeException;
/*     */ import org.apache.batik.script.Interpreter;
/*     */ import org.apache.batik.script.InterpreterException;
/*     */ import org.apache.batik.script.Window;
/*     */ import org.mozilla.javascript.ClassCache;
/*     */ import org.mozilla.javascript.ClassShutter;
/*     */ import org.mozilla.javascript.Context;
/*     */ import org.mozilla.javascript.ContextAction;
/*     */ import org.mozilla.javascript.ContextFactory;
/*     */ import org.mozilla.javascript.Function;
/*     */ import org.mozilla.javascript.JavaScriptException;
/*     */ import org.mozilla.javascript.Script;
/*     */ import org.mozilla.javascript.Scriptable;
/*     */ import org.mozilla.javascript.ScriptableObject;
/*     */ import org.mozilla.javascript.SecurityController;
/*     */ import org.mozilla.javascript.WrapFactory;
/*     */ import org.mozilla.javascript.WrappedException;
/*     */ import org.w3c.dom.events.EventTarget;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class RhinoInterpreter
/*     */   implements Interpreter
/*     */ {
/*  65 */   protected static String[] TO_BE_IMPORTED = { "java.lang", "org.w3c.dom", "org.w3c.dom.css", "org.w3c.dom.events", "org.w3c.dom.smil", "org.w3c.dom.stylesheets", "org.w3c.dom.svg", "org.w3c.dom.views", "org.w3c.dom.xpath" };
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static final int MAX_CACHED_SCRIPTS = 32;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static final String SOURCE_NAME_SVG = "<SVG>";
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static final String BIND_NAME_WINDOW = "window";
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*  96 */   protected static List contexts = new LinkedList();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Window window;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 106 */   protected ScriptableObject globalObject = null;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 111 */   protected LinkedList compiledScripts = new LinkedList();
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 116 */   protected WrapFactory wrapFactory = new BatikWrapFactory(this);
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 121 */   protected ClassShutter classShutter = new RhinoClassShutter();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected RhinoClassLoader rhinoClassLoader;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 135 */   protected SecurityController securityController = new BatikSecurityController();
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 141 */   protected ContextFactory contextFactory = new Factory(this);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Context defaultContext;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public RhinoInterpreter(URL documentURL) {
/*     */     try {
/* 159 */       this.rhinoClassLoader = new RhinoClassLoader(documentURL, getClass().getClassLoader());
/*     */     } catch (SecurityException se) {
/*     */       
/* 162 */       this.rhinoClassLoader = null;
/*     */     } 
/* 164 */     ContextAction initAction = new ContextAction(this) { private final RhinoInterpreter this$0;
/*     */         public Object run(Context cx) {
/* 166 */           ScriptableObject scriptableObject = cx.initStandardObjects(null, false);
/* 167 */           this.this$0.defineGlobalWrapperClass(scriptableObject);
/* 168 */           this.this$0.globalObject = this.this$0.createGlobalObject(cx);
/* 169 */           ClassCache cache = ClassCache.get(this.this$0.globalObject);
/* 170 */           cache.setCachingEnabled((this.this$0.rhinoClassLoader != null));
/*     */           
/* 172 */           StringBuffer sb = new StringBuffer("importPackage(Packages.");
/* 173 */           for (int i = 0; i < RhinoInterpreter.TO_BE_IMPORTED.length - 1; i++) {
/* 174 */             sb.append(RhinoInterpreter.TO_BE_IMPORTED[i]);
/* 175 */             sb.append(");importPackage(Packages.");
/*     */           } 
/* 177 */           sb.append(RhinoInterpreter.TO_BE_IMPORTED[RhinoInterpreter.TO_BE_IMPORTED.length - 1]);
/* 178 */           sb.append(')');
/* 179 */           cx.evaluateString(this.this$0.globalObject, sb.toString(), null, 0, this.this$0.rhinoClassLoader);
/*     */           
/* 181 */           return null;
/*     */         } }
/*     */       ;
/* 184 */     this.contextFactory.call(initAction);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 191 */   public Window getWindow() { return this.window; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 198 */   public ContextFactory getContextFactory() { return this.contextFactory; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected void defineGlobalWrapperClass(Scriptable global) {
/*     */     try {
/* 206 */       ScriptableObject.defineClass(global, WindowWrapper.class);
/* 207 */     } catch (Exception ex) {}
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 216 */   protected ScriptableObject createGlobalObject(Context ctx) { return new WindowWrapper(ctx); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 224 */   public AccessControlContext getAccessControlContext() { return this.rhinoClassLoader.getAccessControlContext(); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 232 */   protected ScriptableObject getGlobalObject() { return this.globalObject; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 244 */   public Object evaluate(Reader scriptreader) throws IOException { return evaluate(scriptreader, "<SVG>"); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Object evaluate(Reader scriptReader, String description) throws IOException {
/* 258 */     ContextAction evaluateAction = new ContextAction(this, scriptReader, description) { private final Reader val$scriptReader;
/*     */         public Object run(Context cx) {
/*     */           try {
/* 261 */             return cx.evaluateReader(this.this$0.globalObject, this.val$scriptReader, this.val$description, 1, this.this$0.rhinoClassLoader);
/*     */           
/*     */           }
/*     */           catch (IOException ioe) {
/*     */             
/* 266 */             throw new WrappedException(ioe);
/*     */           } 
/*     */         } private final String val$description; private final RhinoInterpreter this$0; }
/*     */       ;
/*     */     try {
/* 271 */       return this.contextFactory.call(evaluateAction);
/*     */     } catch (JavaScriptException e) {
/*     */       
/* 274 */       Object value = e.getValue();
/* 275 */       Exception ex = (value instanceof Exception) ? (Exception)value : e;
/* 276 */       throw new InterpreterException(ex, ex.getMessage(), -1, -1);
/*     */     } catch (WrappedException we) {
/* 278 */       Throwable w = we.getWrappedException();
/* 279 */       if (w instanceof Exception) {
/* 280 */         throw new InterpreterException((Exception)w, w.getMessage(), -1, -1);
/*     */       }
/*     */       
/* 283 */       throw new InterpreterException(w.getMessage(), -1, -1);
/*     */     } catch (InterruptedBridgeException ibe) {
/*     */       
/* 286 */       throw ibe;
/*     */     } catch (RuntimeException re) {
/* 288 */       throw new InterpreterException(re, re.getMessage(), -1, -1);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public Object evaluate(String scriptStr) {
/* 303 */     ContextAction evalAction = new ContextAction(this, scriptStr) { private final String val$scriptStr; private final RhinoInterpreter this$0;
/*     */         public Object run(Context cx) {
/* 305 */           Script script = null;
/* 306 */           RhinoInterpreter.Entry entry = null;
/* 307 */           Iterator it = this.this$0.compiledScripts.iterator();
/*     */ 
/*     */           
/* 310 */           while (it.hasNext()) {
/* 311 */             if ((entry = (RhinoInterpreter.Entry)it.next()).str.equals(this.val$scriptStr)) {
/*     */ 
/*     */ 
/*     */               
/* 315 */               script = entry.script;
/* 316 */               it.remove();
/*     */               
/*     */               break;
/*     */             } 
/*     */           } 
/* 321 */           if (script == null) {
/*     */ 
/*     */ 
/*     */ 
/*     */             
/* 326 */             PrivilegedAction compile = new RhinoInterpreter$4(this, cx);
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */             
/* 338 */             script = (Script)AccessController.doPrivileged(compile);
/*     */             
/* 340 */             if (this.this$0.compiledScripts.size() + 1 > 32)
/*     */             {
/*     */ 
/*     */               
/* 344 */               this.this$0.compiledScripts.removeFirst();
/*     */             }
/*     */             
/* 347 */             this.this$0.compiledScripts.addLast(new RhinoInterpreter.Entry(this.val$scriptStr, script));
/*     */           }
/*     */           else {
/*     */             
/* 351 */             this.this$0.compiledScripts.addLast(entry);
/*     */           } 
/*     */           
/* 354 */           return script.exec(cx, this.this$0.globalObject);
/*     */         } }
/*     */       ;
/*     */     try {
/* 358 */       return this.contextFactory.call(evalAction);
/*     */     } catch (InterpreterException ie) {
/* 360 */       throw ie;
/*     */     } catch (JavaScriptException e) {
/*     */       
/* 363 */       Object value = e.getValue();
/* 364 */       Exception ex = (value instanceof Exception) ? (Exception)value : e;
/* 365 */       throw new InterpreterException(ex, ex.getMessage(), -1, -1);
/*     */     } catch (WrappedException we) {
/* 367 */       Throwable w = we.getWrappedException();
/* 368 */       if (w instanceof Exception) {
/* 369 */         throw new InterpreterException((Exception)w, w.getMessage(), -1, -1);
/*     */       }
/*     */       
/* 372 */       throw new InterpreterException(w.getMessage(), -1, -1);
/*     */     } catch (RuntimeException re) {
/*     */       
/* 375 */       throw new InterpreterException(re, re.getMessage(), -1, -1);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void dispose() {
/* 384 */     if (this.rhinoClassLoader != null) {
/* 385 */       ClassCache cache = ClassCache.get(this.globalObject);
/* 386 */       cache.setCachingEnabled(false);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void bindObject(String name, Object object) {
/* 397 */     this.contextFactory.call(new ContextAction(this, object, name) { private final Object val$object; private final String val$name; private final RhinoInterpreter this$0;
/*     */           public Object run(Context cx) {
/* 399 */             Object o = this.val$object;
/* 400 */             if (this.val$name.equals("window") && this.val$object instanceof Window) {
/* 401 */               ((WindowWrapper)this.this$0.globalObject).window = (Window)this.val$object;
/* 402 */               this.this$0.window = (Window)this.val$object;
/* 403 */               o = this.this$0.globalObject;
/*     */             } 
/*     */             
/* 406 */             Scriptable jsObject = Context.toObject(o, this.this$0.globalObject);
/* 407 */             this.this$0.globalObject.put(this.val$name, this.this$0.globalObject, jsObject);
/* 408 */             return null;
/*     */           } }
/*     */       );
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void callHandler(Function handler, Object arg) {
/* 417 */     this.contextFactory.call(new ContextAction(this, arg, handler) { private final Object val$arg; private final Function val$handler; private final RhinoInterpreter this$0;
/*     */           public Object run(Context cx) {
/* 419 */             Object a = Context.toObject(this.val$arg, this.this$0.globalObject);
/* 420 */             Object[] args = { a };
/* 421 */             this.val$handler.call(cx, this.this$0.globalObject, this.this$0.globalObject, args);
/* 422 */             return null;
/*     */           } }
/*     */       );
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void callMethod(ScriptableObject obj, String methodName, ArgumentsBuilder ab) {
/* 433 */     this.contextFactory.call(new ContextAction(this, obj, methodName, ab) { private final ScriptableObject val$obj; private final String val$methodName;
/*     */           public Object run(Context cx) {
/* 435 */             ScriptableObject.callMethod(this.val$obj, this.val$methodName, this.val$ab.buildArguments());
/*     */             
/* 437 */             return null;
/*     */           }
/*     */           
/*     */           private final RhinoInterpreter.ArgumentsBuilder val$ab;
/*     */           private final RhinoInterpreter this$0; }
/*     */       );
/*     */   }
/*     */   
/*     */   void callHandler(Function handler, Object[] args) {
/* 446 */     this.contextFactory.call(new ContextAction(this, handler, args) { private final Function val$handler; private final Object[] val$args; private final RhinoInterpreter this$0;
/*     */           public Object run(Context cx) {
/* 448 */             this.val$handler.call(cx, this.this$0.globalObject, this.this$0.globalObject, this.val$args);
/* 449 */             return null;
/*     */           } }
/*     */       );
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   void callHandler(Function handler, ArgumentsBuilder ab) {
/* 458 */     this.contextFactory.call(new ContextAction(this, ab, handler) { private final RhinoInterpreter.ArgumentsBuilder val$ab; private final Function val$handler; private final RhinoInterpreter this$0;
/*     */           public Object run(Context cx) {
/* 460 */             Object[] args = this.val$ab.buildArguments();
/* 461 */             this.val$handler.call(cx, this.val$handler.getParentScope(), this.this$0.globalObject, args);
/* 462 */             return null;
/*     */           } }
/*     */       );
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 471 */   Object call(ContextAction action) { return this.contextFactory.call(action); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 485 */   Scriptable buildEventTargetWrapper(EventTarget obj) { return new EventTargetWrapper(this.globalObject, obj, this); }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setOut(Writer out) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 505 */   public Locale getLocale() { return null; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public void setLocale(Locale locale) {}
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/* 529 */   public String formatMessage(String key, Object[] args) { return null; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class Entry
/*     */   {
/*     */     public String str;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Script script;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public Entry(String str, Script script) {
/* 551 */       this.str = str;
/* 552 */       this.script = script;
/*     */     }
/*     */   }
/*     */   
/*     */   protected class Factory extends ContextFactory {
/*     */     private final RhinoInterpreter this$0;
/*     */     
/* 559 */     protected Factory(RhinoInterpreter this$0) { this.this$0 = this$0; }
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected Context makeContext() {
/* 565 */       Context cx = super.makeContext();
/* 566 */       cx.setWrapFactory(this.this$0.wrapFactory);
/* 567 */       cx.setSecurityController(this.this$0.securityController);
/* 568 */       cx.setClassShutter(this.this$0.classShutter);
/* 569 */       if (this.this$0.rhinoClassLoader == null) {
/* 570 */         cx.setOptimizationLevel(-1);
/*     */       }
/* 572 */       return cx;
/*     */     }
/*     */   }
/*     */   
/*     */   public static interface ArgumentsBuilder {
/*     */     Object[] buildArguments();
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-script.jar!\org\apache\batik\script\rhino\RhinoInterpreter.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */