/*     */ package org.apache.batik.script.rhino;
/*     */ 
/*     */ import java.security.AccessControlContext;
/*     */ import java.security.AccessController;
/*     */ import java.security.PrivilegedAction;
/*     */ import org.apache.batik.script.Window;
/*     */ import org.mozilla.javascript.Context;
/*     */ import org.mozilla.javascript.Function;
/*     */ import org.mozilla.javascript.ImporterTopLevel;
/*     */ import org.mozilla.javascript.NativeObject;
/*     */ import org.mozilla.javascript.Scriptable;
/*     */ import org.mozilla.javascript.ScriptableObject;
/*     */ import org.w3c.dom.Document;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ public class WindowWrapper
/*     */   extends ImporterTopLevel
/*     */ {
/*  45 */   private static final Object[] EMPTY_ARGUMENTS = new Object[0];
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected RhinoInterpreter interpreter;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected Window window;
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public WindowWrapper(Context context) {
/*  61 */     super(context);
/*  62 */     String[] names = { "setInterval", "setTimeout", "clearInterval", "clearTimeout", "parseXML", "getURL", "postURL", "alert", "confirm", "prompt" };
/*     */ 
/*     */     
/*  65 */     defineFunctionProperties(names, WindowWrapper.class, 2);
/*     */   }
/*     */ 
/*     */ 
/*     */   
/*  70 */   public String getClassName() { return "Window"; }
/*     */ 
/*     */ 
/*     */   
/*  74 */   public String toString() { return "[object Window]"; }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Object setInterval(Context cx, Scriptable thisObj, Object[] args, Function funObj) {
/*  84 */     int len = args.length;
/*  85 */     WindowWrapper ww = (WindowWrapper)thisObj;
/*  86 */     Window window = ww.window;
/*     */     
/*  88 */     if (len < 2) {
/*  89 */       throw Context.reportRuntimeError("invalid argument count");
/*     */     }
/*  91 */     long to = ((Long)Context.jsToJava(args[1], long.class)).longValue();
/*  92 */     if (args[0] instanceof Function) {
/*  93 */       RhinoInterpreter interp = (RhinoInterpreter)window.getInterpreter();
/*     */ 
/*     */       
/*  96 */       FunctionWrapper fw = new FunctionWrapper(interp, (Function)args[0], EMPTY_ARGUMENTS);
/*     */       
/*  98 */       return Context.toObject(window.setInterval(fw, to), thisObj);
/*     */     } 
/* 100 */     String script = (String)Context.jsToJava(args[0], String.class);
/*     */     
/* 102 */     return Context.toObject(window.setInterval(script, to), thisObj);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Object setTimeout(Context cx, Scriptable thisObj, Object[] args, Function funObj) {
/* 112 */     int len = args.length;
/* 113 */     WindowWrapper ww = (WindowWrapper)thisObj;
/* 114 */     Window window = ww.window;
/* 115 */     if (len < 2) {
/* 116 */       throw Context.reportRuntimeError("invalid argument count");
/*     */     }
/* 118 */     long to = ((Long)Context.jsToJava(args[1], long.class)).longValue();
/* 119 */     if (args[0] instanceof Function) {
/* 120 */       RhinoInterpreter interp = (RhinoInterpreter)window.getInterpreter();
/*     */ 
/*     */       
/* 123 */       FunctionWrapper fw = new FunctionWrapper(interp, (Function)args[0], EMPTY_ARGUMENTS);
/*     */       
/* 125 */       return Context.toObject(window.setTimeout(fw, to), thisObj);
/*     */     } 
/* 127 */     String script = (String)Context.jsToJava(args[0], String.class);
/*     */     
/* 129 */     return Context.toObject(window.setTimeout(script, to), thisObj);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void clearInterval(Context cx, Scriptable thisObj, Object[] args, Function funObj) {
/* 139 */     int len = args.length;
/* 140 */     WindowWrapper ww = (WindowWrapper)thisObj;
/* 141 */     Window window = ww.window;
/* 142 */     if (len >= 1) {
/* 143 */       window.clearInterval(Context.jsToJava(args[0], Object.class));
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void clearTimeout(Context cx, Scriptable thisObj, Object[] args, Function funObj) {
/* 154 */     int len = args.length;
/* 155 */     WindowWrapper ww = (WindowWrapper)thisObj;
/* 156 */     Window window = ww.window;
/* 157 */     if (len >= 1) {
/* 158 */       window.clearTimeout(Context.jsToJava(args[0], Object.class));
/*     */     }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Object parseXML(Context cx, Scriptable thisObj, Object[] args, Function funObj) {
/* 169 */     int len = args.length;
/* 170 */     WindowWrapper ww = (WindowWrapper)thisObj;
/* 171 */     Window window = ww.window;
/* 172 */     if (len < 2) {
/* 173 */       throw Context.reportRuntimeError("invalid argument count");
/*     */     }
/*     */     
/* 176 */     AccessControlContext acc = ((RhinoInterpreter)window.getInterpreter()).getAccessControlContext();
/*     */ 
/*     */     
/* 179 */     Object ret = AccessController.doPrivileged(new PrivilegedAction(window, args) { private final Window val$window; private final Object[] val$args;
/*     */           
/* 181 */           public Object run() { return this.val$window.parseXML((String)Context.jsToJava(this.val$args[0], String.class), (Document)Context.jsToJava(this.val$args[1], Document.class)); }
/*     */            }
/*     */         acc);
/*     */ 
/*     */     
/* 186 */     return Context.toObject(ret, thisObj);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void getURL(Context cx, Scriptable thisObj, Object[] args, Function funObj) {
/* 196 */     int len = args.length;
/* 197 */     WindowWrapper ww = (WindowWrapper)thisObj;
/* 198 */     Window window = ww.window;
/* 199 */     if (len < 2) {
/* 200 */       throw Context.reportRuntimeError("invalid argument count");
/*     */     }
/* 202 */     RhinoInterpreter interp = (RhinoInterpreter)window.getInterpreter();
/*     */     
/* 204 */     String uri = (String)Context.jsToJava(args[0], String.class);
/* 205 */     Window.URLResponseHandler urlHandler = null;
/* 206 */     if (args[1] instanceof Function) {
/* 207 */       urlHandler = new GetURLFunctionWrapper(interp, (Function)args[1], ww);
/*     */     } else {
/*     */       
/* 210 */       urlHandler = new GetURLObjectWrapper(interp, (NativeObject)args[1], ww);
/*     */     } 
/*     */     
/* 213 */     Window.URLResponseHandler fw = urlHandler;
/*     */     
/* 215 */     AccessControlContext acc = ((RhinoInterpreter)window.getInterpreter()).getAccessControlContext();
/*     */ 
/*     */     
/* 218 */     if (len == 2) {
/* 219 */       AccessController.doPrivileged(new PrivilegedAction(window, uri, fw) { private final Window val$window; private final String val$uri; private final Window.URLResponseHandler val$fw;
/*     */             public Object run() {
/* 221 */               this.val$window.getURL(this.val$uri, this.val$fw);
/* 222 */               return null;
/*     */             } }
/*     */           acc);
/*     */     } else {
/* 226 */       AccessController.doPrivileged(new PrivilegedAction(window, uri, fw, args) { private final Window val$window; private final String val$uri; private final Window.URLResponseHandler val$fw; private final Object[] val$args;
/*     */             public Object run() {
/* 228 */               this.val$window.getURL(this.val$uri, this.val$fw, (String)Context.jsToJava(this.val$args[2], String.class));
/*     */ 
/*     */               
/* 231 */               return null;
/*     */             } }
/*     */           acc);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void postURL(Context cx, Scriptable thisObj, Object[] args, Function funObj) {
/* 244 */     int len = args.length;
/* 245 */     WindowWrapper ww = (WindowWrapper)thisObj;
/* 246 */     Window window = ww.window;
/* 247 */     if (len < 3) {
/* 248 */       throw Context.reportRuntimeError("invalid argument count");
/*     */     }
/* 250 */     RhinoInterpreter interp = (RhinoInterpreter)window.getInterpreter();
/*     */     
/* 252 */     String uri = (String)Context.jsToJava(args[0], String.class);
/* 253 */     String content = (String)Context.jsToJava(args[1], String.class);
/* 254 */     Window.URLResponseHandler urlHandler = null;
/* 255 */     if (args[2] instanceof Function) {
/* 256 */       urlHandler = new GetURLFunctionWrapper(interp, (Function)args[2], ww);
/*     */     } else {
/*     */       
/* 259 */       urlHandler = new GetURLObjectWrapper(interp, (NativeObject)args[2], ww);
/*     */     } 
/*     */     
/* 262 */     Window.URLResponseHandler fw = urlHandler;
/*     */ 
/*     */     
/* 265 */     AccessControlContext acc = interp.getAccessControlContext();
/*     */     
/* 267 */     switch (len) {
/*     */       case 3:
/* 269 */         AccessController.doPrivileged(new PrivilegedAction(window, uri, content, fw) { private final Window val$window; private final String val$uri; private final String val$content; private final Window.URLResponseHandler val$fw;
/*     */               public Object run() {
/* 271 */                 this.val$window.postURL(this.val$uri, this.val$content, this.val$fw);
/* 272 */                 return null;
/*     */               } }
/*     */             acc);
/*     */         return;
/*     */       case 4:
/* 277 */         AccessController.doPrivileged(new PrivilegedAction(window, uri, content, fw, args) { private final Window val$window; private final String val$uri;
/*     */               public Object run() {
/* 279 */                 this.val$window.postURL(this.val$uri, this.val$content, this.val$fw, (String)Context.jsToJava(this.val$args[3], String.class));
/*     */ 
/*     */                 
/* 282 */                 return null;
/*     */               } private final String val$content; private final Window.URLResponseHandler val$fw; private final Object[] val$args; }
/*     */             acc);
/*     */         return;
/*     */     } 
/* 287 */     AccessController.doPrivileged(new PrivilegedAction(window, uri, content, fw, args) { private final Window val$window; private final String val$uri; private final String val$content; private final Window.URLResponseHandler val$fw; private final Object[] val$args;
/*     */           public Object run() {
/* 289 */             this.val$window.postURL(this.val$uri, this.val$content, this.val$fw, (String)Context.jsToJava(this.val$args[3], String.class), (String)Context.jsToJava(this.val$args[4], String.class));
/*     */ 
/*     */ 
/*     */             
/* 293 */             return null;
/*     */           } }
/*     */         acc);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static void alert(Context cx, Scriptable thisObj, Object[] args, Function funObj) {
/* 306 */     int len = args.length;
/* 307 */     WindowWrapper ww = (WindowWrapper)thisObj;
/* 308 */     Window window = ww.window;
/* 309 */     if (len >= 1) {
/* 310 */       String message = (String)Context.jsToJava(args[0], String.class);
/*     */       
/* 312 */       window.alert(message);
/*     */     } 
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Object confirm(Context cx, Scriptable thisObj, Object[] args, Function funObj) {
/* 323 */     int len = args.length;
/* 324 */     WindowWrapper ww = (WindowWrapper)thisObj;
/* 325 */     Window window = ww.window;
/* 326 */     if (len >= 1) {
/* 327 */       String message = (String)Context.jsToJava(args[0], String.class);
/*     */       
/* 329 */       if (window.confirm(message)) {
/* 330 */         return Context.toObject(Boolean.TRUE, thisObj);
/*     */       }
/* 332 */       return Context.toObject(Boolean.FALSE, thisObj);
/*     */     } 
/* 334 */     return Context.toObject(Boolean.FALSE, thisObj);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   public static Object prompt(Context cx, Scriptable thisObj, Object[] args, Function funObj) {
/*     */     String defVal, message;
/*     */     Object result;
/* 345 */     WindowWrapper ww = (WindowWrapper)thisObj;
/* 346 */     Window window = ww.window;
/*     */     
/* 348 */     switch (args.length) {
/*     */       case 0:
/* 350 */         result = "";
/*     */         break;
/*     */       case 1:
/* 353 */         message = (String)Context.jsToJava(args[0], String.class);
/*     */         
/* 355 */         result = window.prompt(message);
/*     */         break;
/*     */       default:
/* 358 */         message = (String)Context.jsToJava(args[0], String.class);
/*     */         
/* 360 */         defVal = (String)Context.jsToJava(args[1], String.class);
/*     */         
/* 362 */         result = window.prompt(message, defVal);
/*     */         break;
/*     */     } 
/*     */     
/* 366 */     if (result == null) {
/* 367 */       return null;
/*     */     }
/* 369 */     return Context.toObject(result, thisObj);
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class FunctionWrapper
/*     */     implements Runnable
/*     */   {
/*     */     protected RhinoInterpreter interpreter;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected Function function;
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected Object[] arguments;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public FunctionWrapper(RhinoInterpreter ri, Function f, Object[] args) {
/* 398 */       this.interpreter = ri;
/* 399 */       this.function = f;
/* 400 */       this.arguments = args;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 407 */     public void run() { this.interpreter.callHandler(this.function, this.arguments); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   protected static class GetURLFunctionWrapper
/*     */     implements Window.URLResponseHandler
/*     */   {
/*     */     protected RhinoInterpreter interpreter;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected Function function;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     protected WindowWrapper windowWrapper;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public GetURLFunctionWrapper(RhinoInterpreter ri, Function fct, WindowWrapper ww) {
/* 437 */       this.interpreter = ri;
/* 438 */       this.function = fct;
/* 439 */       this.windowWrapper = ww;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 451 */     public void getURLDone(boolean success, String mime, String content) { this.interpreter.callHandler(this.function, new WindowWrapper.GetURLDoneArgBuilder(success, mime, content, this.windowWrapper)); }
/*     */   }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */   
/*     */   private static class GetURLObjectWrapper
/*     */     implements Window.URLResponseHandler
/*     */   {
/*     */     private RhinoInterpreter interpreter;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private ScriptableObject object;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private WindowWrapper windowWrapper;
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     private static final String COMPLETE = "operationComplete";
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/*     */     public GetURLObjectWrapper(RhinoInterpreter ri, ScriptableObject obj, WindowWrapper ww) {
/* 487 */       this.interpreter = ri;
/* 488 */       this.object = obj;
/* 489 */       this.windowWrapper = ww;
/*     */     }
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */ 
/*     */     
/* 501 */     public void getURLDone(boolean success, String mime, String content) { this.interpreter.callMethod(this.object, "operationComplete", new WindowWrapper.GetURLDoneArgBuilder(success, mime, content, this.windowWrapper)); }
/*     */   }
/*     */ 
/*     */   
/*     */   static class GetURLDoneArgBuilder
/*     */     implements RhinoInterpreter.ArgumentsBuilder
/*     */   {
/*     */     boolean success;
/*     */     
/*     */     String mime;
/*     */     
/*     */     String content;
/*     */     WindowWrapper windowWrapper;
/*     */     
/*     */     public GetURLDoneArgBuilder(boolean success, String mime, String content, WindowWrapper ww) {
/* 516 */       this.success = success;
/* 517 */       this.mime = mime;
/* 518 */       this.content = content;
/* 519 */       this.windowWrapper = ww;
/*     */     }
/*     */     
/*     */     public Object[] buildArguments() {
/* 523 */       NativeObject nativeObject = new NativeObject();
/* 524 */       nativeObject.put("success", nativeObject, this.success ? Boolean.TRUE : Boolean.FALSE);
/*     */       
/* 526 */       if (this.mime != null) {
/* 527 */         nativeObject.put("contentType", nativeObject, Context.toObject(this.mime, this.windowWrapper));
/*     */       }
/*     */       
/* 530 */       if (this.content != null) {
/* 531 */         nativeObject.put("content", nativeObject, Context.toObject(this.content, this.windowWrapper));
/*     */       }
/*     */       
/* 534 */       return new Object[] { nativeObject };
/*     */     }
/*     */   }
/*     */ }


/* Location:              C:\Program Files (x86)\IBM\WebSphere\AppServer\profiles\ctgAppSrv01\installedApps\ctgCell01\MAXIMO.ear\maximouiweb.war\WEB-INF\classes\!\com\ibm\tivoli\maximo\report\control\svgtools\batik-script.jar!\org\apache\batik\script\rhino\WindowWrapper.class
 * Java compiler version: 1 (45.3)
 * JD-Core Version:       1.0.7
 */